//
//  AddCustomContactsTableViewController.m
//  SDKTestApp
//
//  Created by Vidyalaxmi V Shenoy on 26/08/15.
//  Copyright (c) 2015 Robosoft. All rights reserved.
//

#import "CustomContactsViewController.h"
#import "NewContactViewController.h"
#import "CustomContactTableViewCell.h"
#import "CustomContactsSettingsView.h"

@interface CustomContactsViewController () <NewContactViewControllerDelegate, CustomContactsSettingsViewDelegate>

@property (nonatomic, assign) id<CustomContactsViewControllerDelegate> customContactDelegate;

@property (weak, nonatomic) IBOutlet UITableView *customContactsTableView;
@property (weak, nonatomic) IBOutlet UIBarButtonItem *settingsBarButtonItem;
@property (nonatomic) NSMutableArray *customContactsArray;

@end

@implementation CustomContactsViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
    self.customContactsTableView.tableFooterView = [[UIView alloc] initWithFrame:CGRectZero];
    [self.settingsBarButtonItem setImage:[[UIImage imageNamed:@"settings_icon"] imageWithRenderingMode:UIImageRenderingModeAlwaysOriginal]];
    [self.settingsBarButtonItem setTitleTextAttributes:@{NSForegroundColorAttributeName:[UIColor lightGrayColor]} forState:UIControlStateDisabled];
}

- (void)configureWithCustomContacts:(NSArray *)customContacts delegate:(id<CustomContactsViewControllerDelegate>)customContactDelegate
{
    self.customContactsArray = customContacts.mutableCopy;
    self.customContactDelegate = customContactDelegate;
}

-(void) viewWillDisappear:(BOOL)animated
{
    if ([self.navigationController.viewControllers indexOfObject:self] == NSNotFound)
    {
        // back button was pressed.
        if ([self.customContactDelegate respondsToSelector:@selector(customContacts:)])
        {
            [self.customContactDelegate customContacts:self.customContactsArray];
        }
    }
    
    [super viewWillDisappear:animated];
}

#pragma mark - Action methods

- (IBAction)settingsButtonTapped:(id)sender
{
    CustomContactsSettingsView *customContactsSettingsView = [[NSBundle mainBundle] loadNibNamed:@"CustomContactsSettingsView" owner:self options:nil].firstObject;
    customContactsSettingsView.settingsDelegate = self;
    
    [self.customContactsTableView beginUpdates];
    self.customContactsTableView.tableHeaderView = customContactsSettingsView;
    [self.customContactsTableView endUpdates];
    
    self.settingsBarButtonItem.enabled = NO;
}

#pragma mark - Table view data source

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return self.customContactsArray.count + 1; // +1 to show "Add new contact" cell
}


- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    if (indexPath.row == 0)
    {
        // Add new contact cell
        UITableViewCell *addNewContactCell = [tableView dequeueReusableCellWithIdentifier:@"AddContactCell"];
        return addNewContactCell;
    }
    else
    {
        CustomContactTableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:@"CustomContactCellIdentifier" forIndexPath:indexPath];
        cell.selectionStyle = UITableViewCellSelectionStyleNone;
        TCCustomAddressBookContact *contact = self.customContactsArray[indexPath.row - 1];
        [cell configureWithName:contact.profileName email:contact.email phone:contact.phone];
        return cell;
    }
}

- (BOOL)tableView:(UITableView *)tableView canEditRowAtIndexPath:(NSIndexPath *)indexPath
{
    return indexPath.row == 0 ? NO : YES;
}

- (void)tableView:(UITableView *)tableView commitEditingStyle:(UITableViewCellEditingStyle)editingStyle forRowAtIndexPath:(NSIndexPath *)indexPath
{
    if (editingStyle == UITableViewCellEditingStyleDelete)
    {
        [self.customContactsArray removeObjectAtIndex:indexPath.row - 1];
        [tableView deleteRowsAtIndexPaths:@[indexPath] withRowAnimation:UITableViewRowAnimationFade];
    }
}

#pragma mark - UITableViewDelegate methods

- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath
{
    if (indexPath.row == 0)
    {
        return 51.f;
    }
    else
    {
        TCCustomAddressBookContact *contact = self.customContactsArray[indexPath.row - 1];
        return [CustomContactTableViewCell heightForContact:contact];
    }
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    [tableView deselectRowAtIndexPath:indexPath animated:YES];
}

#pragma mark - Navigation

- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender
{
    if ([segue.identifier isEqualToString:@"NewContactSegue"])
    {
        NewContactViewController *newContactViewController = (NewContactViewController *)segue.destinationViewController;
        newContactViewController.delegate = self;
    }
}

#pragma NewContactViewControllerDelegate methods

- (void)newContactViewController:(NewContactViewController *)newContactViewController addedContact:(TCCustomAddressBookContact *)contact
{
    if (!self.customContactsArray)
    {
        self.customContactsArray = [NSMutableArray array];
    }
    
    [self.customContactsArray addObject:contact];
    [self.customContactsTableView insertRowsAtIndexPaths:@[[NSIndexPath indexPathForRow:self.customContactsArray.count inSection:0]] withRowAnimation:UITableViewRowAnimationAutomatic];
}

#pragma mark - CustomContactsSettingsViewDelegate methods

- (void)doneButtonTappedFromcustomContactsSettingsView:(CustomContactsSettingsView *)settingsView
{
    [self.customContactsTableView beginUpdates];
    self.customContactsTableView.tableHeaderView = nil;
    [self.customContactsTableView endUpdates];
    
    self.settingsBarButtonItem.enabled = YES;
}

@end
