//
//  NewContactViewController.m
//  SDKTestApp
//
//  Created by Vidyalaxmi V Shenoy on 26/08/15.
//  Copyright (c) 2015 Robosoft. All rights reserved.
//

#import "NewContactViewController.h"

@interface NewContactViewController ()

@property (weak, nonatomic) IBOutlet UITextField *profileNameTextField;
@property (weak, nonatomic) IBOutlet UITextField *emailTextField;
@property (weak, nonatomic) IBOutlet UITextField *phoneTextField;
@property (weak, nonatomic) IBOutlet UIScrollView *scrollView;

@property (nonatomic) UITextField *activeTextField;

@end

@implementation NewContactViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
    
    [self addInputAccessoryViewForTextField:self.phoneTextField];
    
    [self registerToKeyboardNotifications];
}

- (void)addInputAccessoryViewForTextField:(UITextField *)textField
{
    CGRect accessFrame = CGRectMake(0.0, 0.0, 768.0, 44.0);
    UIView *inputAccessoryView = [[UIView alloc] initWithFrame:accessFrame];
    
    UIButton *doneButton = [[UIButton alloc] initWithFrame:CGRectMake([UIScreen mainScreen].bounds.size.width - 75, 0.0, 90, 44.0)];
    [doneButton setTitle:@"Set"
                forState:UIControlStateNormal];
    
    [doneButton addTarget:self
                   action:@selector(setButtonTapped:)
         forControlEvents:UIControlEventTouchUpInside];
    
    [inputAccessoryView addSubview:doneButton];
    inputAccessoryView.backgroundColor = [UIColor colorWithRed:156.f/255.f green:163.f/255.f blue:177.f/255.f alpha:1];
    textField.inputAccessoryView = inputAccessoryView;
}


- (void)registerToKeyboardNotifications
{
    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(keyboardDidShow:)
                                                 name:UIKeyboardDidShowNotification
                                               object:nil];
    
    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(keyboardWillBeHidden:)
                                                 name:UIKeyboardWillHideNotification
                                               object:nil];
}

#pragma mark - Action methods

- (void)keyboardDidShow:(NSNotification *)notification
{
    NSDictionary* info = [notification userInfo];
    CGRect kbRect = [[info objectForKey:UIKeyboardFrameBeginUserInfoKey] CGRectValue];
    kbRect = [self.view convertRect:kbRect fromView:nil];
    
    UIEdgeInsets contentInsets = UIEdgeInsetsMake(0.0, 0.0, kbRect.size.height, 0.0);
    self.scrollView.contentInset = contentInsets;
    self.scrollView.scrollIndicatorInsets = contentInsets;
    
    CGRect aRect = self.view.frame;
    aRect.size.height -= kbRect.size.height;
    if (!CGRectContainsPoint(aRect, self.activeTextField.frame.origin) ) {
        [self.scrollView scrollRectToVisible:self.activeTextField.frame animated:YES];
    }
}

- (void)keyboardWillBeHidden:(NSNotification *)notification
{
    UIEdgeInsets contentInsets = UIEdgeInsetsZero;
    self.scrollView.contentInset = contentInsets;
    self.scrollView.scrollIndicatorInsets = contentInsets;
}

- (void)setButtonTapped:(id)sender
{
    [self.view endEditing:YES];
}

- (IBAction)addContactButtonTapped:(id)sender
{
    if (!self.profileNameTextField.text.length )
    {
        [self showFailureAlertWithMessage:@"Please fill profile name field"];
    }
    else if (!self.phoneTextField.text.length && !self.emailTextField.text.length)
    {
        [self showFailureAlertWithMessage:@"Please fill phone or email field"];
    }
    else
    {
        [self.view endEditing:YES];
        [self dismissViewControllerAnimated:YES completion:^{
            TCCustomAddressBookContact *contact = [TCCustomAddressBookContact new];
            contact.profileName = self.profileNameTextField.text;
            contact.email = self.emailTextField.text;
            contact.phone = self.phoneTextField.text;
            
            if ([self.delegate respondsToSelector:@selector(newContactViewController:addedContact:)])
            {
                [self.delegate newContactViewController:self addedContact:contact];
            }
        }];
    }
}

- (IBAction)viewTapHandler:(id)sender
{
    [self.view endEditing:YES];
}

- (IBAction)cancelButtonTapped:(id)sender
{
    [self dismissViewControllerAnimated:YES completion:nil];
}

- (void)showFailureAlertWithMessage:(NSString *)message
{
    [[[UIAlertView alloc] initWithTitle:@"Failed" message:message
                               delegate:nil cancelButtonTitle:@"OK" otherButtonTitles:nil, nil] show];
}

#pragma mark - UITextFieldDelegate methods

- (BOOL)textFieldShouldReturn:(UITextField *)textField
{
    [textField resignFirstResponder];
    return YES;
}

- (void)textFieldDidBeginEditing:(UITextField *)textField
{
    self.activeTextField = textField;
}

- (void)textFieldDidEndEditing:(UITextField *)textField
{
    self.activeTextField = nil;
}

- (void)dealloc
{
    [[NSNotificationCenter defaultCenter] removeObserver:self];
}

@end
