//
//  RoomsListTableViewController.m
//  SDKTestApp
//
//  Created by Vidyalaxmi V Shenoy on 27/08/15.
//  Copyright (c) 2015 Robosoft. All rights reserved.
//

#import "RoomsListTableViewController.h"
#import <TeamchatSDK/TeamchatSDK.h>
#import "SVProgressHUD.h"

@interface RoomsListTableViewController ()

@property (nonatomic) NSArray *groupsListArray;

@end

@implementation RoomsListTableViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
    self.tableView.tableFooterView = [[UIView alloc] initWithFrame:CGRectZero];
    
    __weak RoomsListTableViewController *weakSelf = self;
    
    [SVProgressHUD showWithMaskType:SVProgressHUDMaskTypeBlack];
    [Teamchat initWithCompletionHandler:^(BOOL success, NSError *error, NSString *errMsg) {
        [SVProgressHUD dismiss];
        if (success)
        {
            NSError *groupsError = [NSError new];
            NSArray *groups = [Teamchat teamchatGroups:&groupsError];
            if (groups)
            {
                weakSelf.groupsListArray = groups;
                [weakSelf.tableView reloadData];
            }
            else
            {
                [weakSelf showFailureAlertWithMessage:[groupsError localizedDescription]];
            }
        }
        else
        {
            [weakSelf showFailureAlertWithMessage:[error localizedDescription]];
        }
    }];
}

- (void)showFailureAlertWithMessage:(NSString *)alertMessage
{
    [[[UIAlertView alloc] initWithTitle:@"Failed" message:alertMessage
                               delegate:nil cancelButtonTitle:@"OK" otherButtonTitles:nil, nil]
     show];
}

#pragma mark - Table view data source

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return self.groupsListArray.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:@"GroupsListCell" forIndexPath:indexPath];

    TeamchatGroup *group = self.groupsListArray[indexPath.row];

    cell.textLabel.text = [NSString stringWithFormat:@"Group Name : %@", group.name];
    cell.detailTextLabel.text = [NSString stringWithFormat:@"Group ID : %@", group.groupID];
    
    return cell;
}

#pragma mark - UITableViewDelegate methods

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    [Teamchat setLoggingEnabled:YES];
    [tableView deselectRowAtIndexPath:indexPath animated:YES];
    TeamchatGroup *group = self.groupsListArray[indexPath.row];
    
    [Teamchat initWithCompletionHandler:^(BOOL success, NSError *error, NSString *errMsg) {
        if (success)
        {
            UIViewController *groupViewController = [Teamchat createTeamchatWindowViewControllerWithGroup:group];
            if (groupViewController)
            {
                [self.navigationController pushViewController:groupViewController animated:YES];
            }
        }
        else
        {
            [self showFailureAlertWithMessage:[error localizedDescription]];
        }
    }];
    
}

@end
